==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/is.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Veita aðgengi",
    "Error configuring OAuth2" : "Villa við uppsetningu OAuth2",
    "Generate keys" : "Útbúa lykla",
    "Error generating key pair" : "Villa við að útbúa nýtt lyklapar",
    "Forbidden to manage local mounts" : "Bannað að stjórna staðværum tengipunktum",
    "Storage with ID \"%d\" not found" : "Geymsla með auðkennið '%d' fannst ekki",
    "Invalid backend or authentication mechanism class" : "Ógildur flokkur bakenda eða auðkenningartækni",
    "Invalid mount point" : "Ógildur tengipunktur",
    "Objectstore forbidden" : "Hlutageymsla (objectstore) bönnuð",
    "Invalid storage backend \"%s\"" : "Ógildur geymslubakendi \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ekki leyft að nota \"%s\" bakendann",
    "Not permitted to use authentication mechanism \"%s\"" : "Ekki leyft að nota \"%s\" auðkenningartæknina",
    "Unsatisfied backend parameters" : "Óuppfyllt viðföng bakenda",
    "Unsatisfied authentication mechanism parameters" : "Óuppfyllt viðföng auðkenningartækni",
    "Insufficient data: %s" : "Ónóg gögn: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Geymslan með auðkennið '%d' er ekki breytanleg af venjulegum notanda",
    "Access key" : "Aðgangslykill",
    "Secret key" : "Leynilykill",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "OAuth2" : "OAuth2",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Innskráning",
    "Password" : "Lykilorð",
    "Tenant name" : "Nafn handhafa (tenant)",
    "Identity endpoint URL" : "Endapunktur auðkennisslóðar (identity endpoint URL)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Lén",
    "Rackspace" : "Rackspace",
    "API key" : "API-lykill",
    "Global credentials" : "Víðvær innskráningarauðkenni",
    "Log-in credentials, save in database" : "Innskráningarauðkenni, vista í gagnagrunni",
    "Login and password" : "Notandanafn og lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "Global credentials, manually entered" : "Víðvær innskráningarauðkenni, sett inn handvirkt",
    "Manually entered, store in database" : "Sett inn handvirkt, geyma í gagnagrunni",
    "RSA public key" : "RSA-dreifilykill",
    "Public key" : "Dreifilykill",
    "RSA private key" : "RSA-einkalykill",
    "Private key" : "Einkalykill",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Sjálfgefið Kerberos svæði, er sjálfgefið \"WORKGROUP\"",
    "Kerberos ticket" : "Kerberos aðgöngumerki",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Vélarheiti",
    "Port" : "Gátt",
    "Region" : "Svæði",
    "Storage Class" : "Flokkur geymslurýmis",
    "Enable SSL" : "Virkja SSL",
    "Enable Path Style" : "Virkja slóðastíl",
    "Legacy (v2) authentication" : "Eldri (v2) auðkenning",
    "WebDAV" : "WebDAV",
    "URL" : "Slóð (URL)",
    "Remote subfolder" : "Fjartengd undirmappa",
    "Secure https://" : "Öruggt https://",
    "FTP" : "FTP",
    "Host" : "Netþjónn",
    "Secure ftps://" : "Öruggt ftps://",
    "Local" : "Staðvært",
    "Location" : "Staðsetning",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rót (root)",
    "SFTP with secret key login" : "SFTP innskráning með leynilykli",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Deila",
    "Show hidden files" : "Sýna faldar skrár",
    "Case sensitive file system" : "Skráakerfi háð há/lágstöfum",
    "Verify ACL access when listing files" : "Athuga ACL-aðgang þegar gerðir eru listar yfir skrár",
    "Timeout" : "Tímamörk",
    "SMB/CIFS using OC login" : "SMB / CIFS með OC-innskráningu",
    "Login as share" : "Skrá inn sem sameign",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Heiti á þjónustu",
    "Request timeout (seconds)" : "Tímamörk á beiðni (sekúndur)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við cURL í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við FTP í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" er ekki uppsett. Tenging %2$s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "External storage" : "Ytri gagnageymsla",
    "External storage support" : "Stuðningur við utanaðkomandi gagnageymslur",
    "Adds basic external storage support" : "Bætir við grunnstuðningi fyrir utanaðkomandi gagnageymslur",
    "Confirm" : "Staðfesta",
    "Storage credentials" : "Innskráningarauðkenni á gagnageymslu",
    "Enter the storage login" : "Settu inn notandanafn fyrir gagnageymsluna",
    "Enter the storage password" : "Settu inn lykilorð fyrir gagnageymsluna",
    "Unable to update this external storage config. {statusMessage}" : "Tókst ekki að uppfæra uppsetningu þessarar ytri-gagnageymslu. {statusMessage}",
    "New configuration successfully saved" : "Það tókst að vista nýju uppsetninguna",
    "Enter missing credentials" : "Settu inn auðkenni sem vantar",
    "There was an error with this external storage." : "Það kom upp villa með þessa ytri-gagnageymslu.",
    "We were unable to check the external storage {basename}" : "Okkur tókst ekki að athuga ytri-gagnageymsluna {basename}",
    "Examine this faulty external storage configuration" : "Skoða þessa ófullgerðu uppsetningu ytri-gagnageymslu",
    "Open in Files" : "Opna í skráaforritinu",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Það kom upp villa með þessa ytri-gagnageymslu. Viltu yfirfara uppsetningu þessa tengipunkts á stillingasíðunni?",
    "External mount error" : "Villa við tengingu í fjartengdu skráakerfi",
    "List of external storage." : "Listi yfir ytri-gagnageymslur.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Engin utanaðkomandi gagnageymsla er uppsett. Þú getur stillt slíkt í einkastillingunum þínum.",
    "There is no external storage configured and you don't have the permission to configure them." : "Engin utanaðkomandi gagnageymsla er uppsett og þú hefur ekki heimild til að stilla slíkt.",
    "No external storage" : "Engin ytri-gagnageymsla",
    "Storage type" : "Tegund gagnageymslu",
    "Unknown" : "Óþekkt",
    "Scope" : "Umfang",
    "Personal" : "Einka",
    "System" : "Kerfi",
    "Type to select account or group." : "Skrifaðu til að velja notandaaðgang eða hóp.",
    "(Group)" : "(Hópur)",
    "Compatibility with Mac NFD encoding (slow)" : "Samhæfni við Mac NFD kóðun (hægvirkt)",
    "Enable encryption" : "Virkja dulritun",
    "Enable previews" : "Virkja forskoðanir",
    "Enable sharing" : "Virkja deilingu",
    "Check for changes" : "Fylgjast með breytingum",
    "Never" : "Aldrei",
    "Once every direct access" : "Einu sinni við hvern beinan aðgang",
    "Read only" : "Skrifvarið",
    "Disconnect" : "Aftengjast",
    "Unknown backend: {backendName}" : "Óþekktur bakendi: {backendName}",
    "Admin defined" : "Skilgreindur kerfisstjóri",
    "Delete storage?" : "Eyða geymslu?",
    "Click to recheck the configuration" : "Smelltu til að yfirfara aftur uppsetninguna",
    "Saved" : "Vistað",
    "Saving …" : "Vista …",
    "Save" : "Vista",
    "No external storage configured or you don't have the permission to configure them" : "Engin utanaðkomandi gagnageymsla er uppsett eða að þú hefur ekki heimild til að stilla slíkt",
    "Open documentation" : "Opna hjálparskjöl",
    "Folder name" : "Nafn möppu",
    "Authentication" : "Auðkenning",
    "Configuration" : "Uppsetning",
    "Available for" : "Tiltækt fyrir",
    "Add storage" : "Bæta við gagnahirslu",
    "All people" : "Allt fólk",
    "Advanced settings" : "Ítarlegri valkostir",
    "Allow people to mount external storage" : "Leyfa notendum að tengja ytri gagnageymslur í skráakerfi",
    "Error configuring OAuth1" : "Villa við uppsetningu OAuth1",
    "Please provide a valid app key and secret." : "Settu inn gildan forritslykil og leynilykil (secret).",
    "OAuth1" : "OAuth1",
    "App key" : "Lykill forrits",
    "App secret" : "Leynilykill forrits",
    "Saving …" : "Vista …"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/is.js <==
OC.L10N.register(
    "files_external",
    {
    "Forbidden to manage local mounts" : "Bannað að stjórna staðværum tengipunktum",
    "Storage with ID \"%d\" not found" : "Geymsla með auðkennið '%d' fannst ekki",
    "Invalid backend or authentication mechanism class" : "Ógildur flokkur bakenda eða auðkenningartækni",
    "Invalid mount point" : "Ógildur tengipunktur",
    "Objectstore forbidden" : "Hlutageymsla (objectstore) bönnuð",
    "Invalid storage backend \"%s\"" : "Ógildur geymslubakendi \"%s\"",
    "Not permitted to use backend \"%s\"" : "Ekki leyft að nota \"%s\" bakendann",
    "Not permitted to use authentication mechanism \"%s\"" : "Ekki leyft að nota \"%s\" auðkenningartæknina",
    "Unsatisfied backend parameters" : "Óuppfyllt viðföng bakenda",
    "Unsatisfied authentication mechanism parameters" : "Óuppfyllt viðföng auðkenningartækni",
    "Insufficient data: %s" : "Ónóg gögn: %s",
    "Storage with ID \"%d\" is not editable by non-admins" : "Geymslan með auðkennið '%d' er ekki breytanleg af venjulegum notanda",
    "Access key" : "Aðgangslykill",
    "Secret key" : "Leynilykill",
    "Builtin" : "Innbyggt",
    "None" : "Ekkert",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Innskráning",
    "Password" : "Lykilorð",
    "Tenant name" : "Nafn handhafa (tenant)",
    "Identity endpoint URL" : "Endapunktur auðkennisslóðar (identity endpoint URL)",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Lén",
    "Rackspace" : "Rackspace",
    "API key" : "API-lykill",
    "Global credentials" : "Víðvær innskráningarauðkenni",
    "Log-in credentials, save in database" : "Innskráningarauðkenni, vista í gagnagrunni",
    "Login and password" : "Notandanafn og lykilorð",
    "Log-in credentials, save in session" : "Innskráningarauðkenni, vista í setu",
    "Global credentials, manually entered" : "Víðvær innskráningarauðkenni, sett inn handvirkt",
    "Manually entered, store in database" : "Sett inn handvirkt, geyma í gagnagrunni",
    "RSA public key" : "RSA-dreifilykill",
    "Public key" : "Dreifilykill",
    "RSA private key" : "RSA-einkalykill",
    "Private key" : "Einkalykill",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Sjálfgefið Kerberos svæði, er sjálfgefið \"WORKGROUP\"",
    "Kerberos ticket" : "Kerberos aðgöngumerki",
    "Bucket" : "Bucket",
    "Hostname" : "Vélarheiti",
    "Port" : "Gátt",
    "Proxy" : "Milliþjónn",
    "Region" : "Svæði",
    "Storage Class" : "Flokkur geymslurýmis",
    "Enable SSL" : "Virkja SSL",
    "Enable Path Style" : "Virkja slóðastíl",
    "Legacy (v2) authentication" : "Eldri (v2) auðkenning",
    "WebDAV" : "WebDAV",
    "URL" : "Slóð (URL)",
    "Remote subfolder" : "Fjartengd undirmappa",
    "Secure https://" : "Öruggt https://",
    "FTP" : "FTP",
    "Host" : "Netþjónn",
    "Secure ftps://" : "Öruggt ftps://",
    "Local" : "Staðvært",
    "Location" : "Staðsetning",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Rót (root)",
    "SFTP with secret key login" : "SFTP innskráning með leynilykli",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Deila",
    "Show hidden files" : "Sýna faldar skrár",
    "Case sensitive file system" : "Skráakerfi háð há/lágstöfum",
    "Verify ACL access when listing files" : "Athuga ACL-aðgang þegar gerðir eru listar yfir skrár",
    "Timeout" : "Tímamörk",
    "SMB/CIFS using OC login" : "SMB / CIFS með OC-innskráningu",
    "Login as share" : "Skrá inn sem sameign",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Heiti á þjónustu",
    "Request timeout (seconds)" : "Tímamörk á beiðni (sekúndur)",
    "External storage" : "Ytri gagnageymsla",
    "External storage support" : "Stuðningur við utanaðkomandi gagnageymslur",
    "Adds basic external storage support" : "Bætir við grunnstuðningi fyrir utanaðkomandi gagnageymslur",
    "Add storage" : "Bæta við gagnahirslu",
    "Folder name" : "Nafn möppu",
    "Authentication" : "Auðkenning",
    "Cancel" : "Cancel",
    "Edit" : "Breyta",
    "Create" : "Búa til",
    "Never" : "Aldrei",
    "Once every direct access" : "Einu sinni við hvern beinan aðgang",
    "Read only" : "Skrifvarið",
    "Enable previews" : "Virkja forskoðanir",
    "Enable sharing" : "Virkja deilingu",
    "Enable encryption" : "Virkja dulritun",
    "Compatibility with Mac NFD encoding (slow)" : "Samhæfni við Mac NFD kóðun (hægvirkt)",
    "External storages" : "Utanáliggjandi gagnageymslur",
    "Actions" : "Aðgerðir",
    "Delete" : "Eyða",
    "Saved" : "Vistað",
    "Error while saving" : "Villa við vistun",
    "Allow people to mount external storage" : "Leyfa notendum að tengja ytri gagnageymslur í skráakerfi",
    "Error generating key pair" : "Villa við að útbúa nýtt lyklapar",
    "Key size" : "Lykilstærð",
    "Generate keys" : "Útbúa lykla",
    "Confirm" : "Staðfesta",
    "Storage credentials" : "Innskráningarauðkenni á gagnageymslu",
    "Enter the storage login" : "Settu inn notandanafn fyrir gagnageymsluna",
    "Enter the storage password" : "Settu inn lykilorð fyrir gagnageymsluna",
    "Saving …" : "Vista …",
    "Save" : "Vista",
    "Unable to update this external storage config. {statusMessage}" : "Tókst ekki að uppfæra uppsetningu þessarar ytri-gagnageymslu. {statusMessage}",
    "New configuration successfully saved" : "Það tókst að vista nýju uppsetninguna",
    "Enter missing credentials" : "Settu inn auðkenni sem vantar",
    "There was an error with this external storage." : "Það kom upp villa með þessa ytri-gagnageymslu.",
    "We were unable to check the external storage {basename}" : "Okkur tókst ekki að athuga ytri-gagnageymsluna {basename}",
    "Examine this faulty external storage configuration" : "Skoða þessa ófullgerðu uppsetningu ytri-gagnageymslu",
    "Open in Files" : "Opna í skráaforritinu",
    "External mount error" : "Villa við tengingu í fjartengdu skráakerfi",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "Það kom upp villa með þessa ytri-gagnageymslu. Viltu yfirfara uppsetningu þessa tengipunkts á stillingasíðunni?",
    "Open settings" : "Opna stillingar",
    "Ignore" : "Hunsa",
    "List of external storage." : "Listi yfir ytri-gagnageymslur.",
    "There is no external storage configured. You can configure them in your Personal settings." : "Engin utanaðkomandi gagnageymsla er uppsett. Þú getur stillt slíkt í einkastillingunum þínum.",
    "There is no external storage configured and you don't have the permission to configure them." : "Engin utanaðkomandi gagnageymsla er uppsett og þú hefur ekki heimild til að stilla slíkt.",
    "No external storage" : "Engin ytri-gagnageymsla",
    "Storage type" : "Tegund gagnageymslu",
    "Unknown" : "Óþekkt",
    "Scope" : "Umfang",
    "Personal" : "Einka",
    "System" : "Kerfi",
    "Connected" : "Tengt",
    "Error" : "Villa",
    "Unauthorized" : "Ekki heimilað",
    "Network error" : "Villa í netkerfi",
    "Grant access" : "Veita aðgengi",
    "Error configuring OAuth1" : "Villa við uppsetningu OAuth1",
    "Please provide a valid app key and secret." : "Settu inn gildan forritslykil og leynilykil (secret).",
    "Error configuring OAuth2" : "Villa við uppsetningu OAuth2",
    "%s" : "%s",
    "OAuth1" : "OAuth1",
    "App key" : "Lykill forrits",
    "App secret" : "Leynilykill forrits",
    "OAuth2" : "OAuth2",
    "Client ID" : "Biðlaraauðkenni",
    "Client secret" : "Leynilykill biðlara",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við cURL í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Stuðningur við FTP í PHP er ekki virkjaður eða ekki uppsettur. Tenging %s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" er ekki uppsett. Tenging %2$s í skráakerfi er ekki möguleg. Biddu kerfisstjórann þinn um að setja þetta upp.",
    "Type to select account or group." : "Skrifaðu til að velja notandaaðgang eða hóp.",
    "(Group)" : "(Hópur)",
    "Check for changes" : "Fylgjast með breytingum",
    "Disconnect" : "Aftengjast",
    "Unknown backend: {backendName}" : "Óþekktur bakendi: {backendName}",
    "Admin defined" : "Skilgreindur kerfisstjóri",
    "Delete storage?" : "Eyða geymslu?",
    "Click to recheck the configuration" : "Smelltu til að yfirfara aftur uppsetninguna",
    "Saving …" : "Vista …",
    "No external storage configured or you don't have the permission to configure them" : "Engin utanaðkomandi gagnageymsla er uppsett eða að þú hefur ekki heimild til að stilla slíkt",
    "Open documentation" : "Opna hjálparskjöl",
    "Configuration" : "Uppsetning",
    "Available for" : "Tiltækt fyrir",
    "All people" : "Allt fólk",
    "Advanced settings" : "Ítarlegri valkostir"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
